@@ -11,7 +11,7 @@ use Mojo::JSON::Pointer;
 use Mojo::JSON;
 use Mojo::Loader;
 use Mojo::URL;
-use Mojo::Util 'url_unescape';
+use Mojo::Util qw(url_unescape sha1_sum);
 use Scalar::Util qw(blessed refaddr);
 use Time::Local ();
 
@@ -24,7 +24,7 @@ use constant VALIDATE_HOSTNAME => eval 'require Data::Validate::Domain;1';
 use constant VALIDATE_IP       => eval 'require Data::Validate::IP;1';
 
 our $ERR;    # ugly hack to improve validation errors
-our $VERSION = '2.02';
+our $VERSION = '2.03';
 our @EXPORT_OK = 'validate_json';
 
 my $BUNDLED_CACHE_DIR = path(path(__FILE__)->dirname, qw(Validator cache));
@@ -49,7 +49,6 @@ has ua => sub {
 
 sub bundle {
   my ($self, $args) = @_;
-  my $def_name_cb = $args->{definitions_name} || \&_definitions_name;
   my @topics = ([undef, my $bundle = {}]);
   my ($cloner, $tied);
 
@@ -66,16 +65,26 @@ sub bundle {
     };
   }
   else {
-    $bundle->{definitions} ||= {%{$topics[0][0]{definitions} || {}}};
+    my $ref_key = $args->{ref_key} || 'x-bundled';
+    $bundle->{$ref_key} = $topics[0][0]{$ref_key} || {};
     $cloner = sub {
       my $from = shift;
       my $ref  = ref $from;
 
       if ($ref eq 'HASH' and my $tied = tied %$from) {
-        return $from if $tied->fqn =~ m!^$self->{root_schema_url}\#!;
-        my $name = $self->$def_name_cb($tied->fqn);
-        push @topics, [$tied->schema, $bundle->{definitions}{$name} = {}];
-        tie my %ref, 'JSON::Validator::Ref', $tied->schema, "#/definitions/$name";
+        my $ref_name = $tied->fqn;
+        return $from if $ref_name =~ m!^$self->{root_schema_url}\#!;
+
+        if (-e $ref_name) {
+          $ref_name = sprintf '%s-%s', substr(sha1_sum($ref_name), 0, 10),
+            path($ref_name)->basename;
+        }
+        else {
+          $ref_name =~ s![^\w-]!_!g;
+        }
+
+        push @topics, [$tied->schema, $bundle->{$ref_key}{$ref_name} = {}];
+        tie my %ref, 'JSON::Validator::Ref', $tied->schema, "#/$ref_key/$ref_name";
         return \%ref;
       }
 
@@ -819,13 +828,6 @@ sub _cmp {
   return "";
 }
 
-sub _definitions_name {
-  local $_ = "$_[1]";
-  s!\#!-!g;
-  s![^\w-]!_!g;
-  return "_$_";
-}
-
 sub _expected {
   my $type = _guess_data_type($_[1]);
   return "Expected $_[0] - got different $type." if $_[0] =~ /\b$type\b/;
@@ -985,7 +987,7 @@ JSON::Validator - Validate data against a JSON schema
 
 =head1 VERSION
 
-2.02
+2.03
 
 =head1 SYNOPSIS
 
